" Special
let wallpaper  = "{wallpaper}"
let background = "{background}"
let foreground = "{foreground}"
let cursor     = "{cursor}"

" Colors
let color0  = "{color0}"
let color1  = "{color1}"
let color2  = "{color2}"
let color3  = "{color3}"
let color4  = "{color4}"
let color5  = "{color5}"
let color6  = "{color6}"
let color7  = "{color7}"
let color8  = "{color8}"
let color9  = "{color9}"
let color10 = "{color10}"
let color11 = "{color11}"
let color12 = "{color12}"
let color13 = "{color13}"
let color14 = "{color14}"
let color15 = "{color15}"
